@@ -335,6 +335,7 @@ class Client:
         model_id: Optional[str] = None,
         experiment_id: Optional[str] = None,
         model: Optional[Model] = None,
+        threshold: Optional[float] = None,
     ) -> Prediction:
         """
         Predict model with test iid data.
@@ -366,6 +367,7 @@ class Client:
             model_id=model_id,
             experiment_id=experiment_id,
             model=model,
+            threshold=threshold,
         )
 
         prediction = Prediction(
@@ -485,3 +487,14 @@ class Client:
                 List of uploaded table information.
         """
         return self.api.get_table_list()
+    
+    def get_model_list(self, experiment_id) -> List[str]:
+        """
+        Return list of model in specific experiment_id.
+
+        Returns:
+        ----------
+            (List[str])
+                List of experiment information.
+        """
+        return self.api.get_model_list(experiment_id)
